==> qtjambi-webenginewidgets-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWebEngineWidgets/QWebEngineProfile_shell.h <==
#ifndef QWEBENGINEPROFILE_SHELL_H
#define QWEBENGINEPROFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWebEngineWidgets/qwebengineprofile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtWebEngineCore/QWebEngineNotification>
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <QtWebEngineWidgets/qwebenginedownloaditem.h>
#include <QtWebEngineWidgets/qwebenginescriptcollection.h>
#include <QtWebEngineWidgets/qwebenginesettings.h>
#include <QtJambi/RegistryAPI>


class QWebEngineProfile_shell : public QWebEngineProfile, public QtJambiShellInterface
{
public:
    QWebEngineProfile_shell(QObject* parent0 = nullptr);
    QWebEngineProfile_shell(const QString& name0, QObject* parent1 = nullptr);
    ~QWebEngineProfile_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEngineProfile_access : public QWebEngineProfile
{
};

#endif // QWEBENGINEPROFILE_SHELL_H

==> qtjambi-webenginewidgets-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiWebEngineWidgets/QWebEngineProfile_shell.h <==
#ifndef QWEBENGINEPROFILE_SHELL_H
#define QWEBENGINEPROFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineWidgets/qwebengineprofile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/JObjectWrapper>
#include <QtJambi/JavaAPI>
#include <QtWebEngineCore/QWebEngineNotification>
#if __has_include(<QtWebEngineCore/qwebengineclientcertificatestore.h>)
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#endif
#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <QtWebEngineWidgets/qwebenginedownloaditem.h>
#include <QtWebEngineWidgets/qwebenginescriptcollection.h>
#include <QtWebEngineWidgets/qwebenginesettings.h>
#include <QtJambi/RegistryAPI>


class QWebEngineProfile_shell : public QWebEngineProfile, public QtJambiShellInterface
{
public:
    QWebEngineProfile_shell(QObject* parent0 = nullptr);
    QWebEngineProfile_shell(const QString& name0, QObject* parent1 = nullptr);
    ~QWebEngineProfile_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QWebEngineProfile_access : public QWebEngineProfile
{
};

#endif // QWEBENGINEPROFILE_SHELL_H
